@@ -7,6 +7,7 @@ from decimal import Decimal
 import msgpack
 from msgpack import ExtType
 
+from python3_commons.serializers.common import ExtendedType
 from python3_commons.serializers.json import CustomJSONEncoder
 
 logger = logging.getLogger(__name__)
@@ -14,26 +15,27 @@ logger = logging.getLogger(__name__)
 
 def msgpack_encoder(obj):
     if isinstance(obj, Decimal):
-        return ExtType(1, str(obj).encode())
+        return ExtType(ExtendedType.DECIMAL, str(obj).encode())
     elif isinstance(obj, datetime):
-        return ExtType(2, obj.isoformat().encode())
+        return ExtType(ExtendedType.DATETIME, obj.isoformat().encode())
     elif isinstance(obj, date):
-        return ExtType(3, obj.isoformat().encode())
+        return ExtType(ExtendedType.DATE, obj.isoformat().encode())
     elif dataclasses.is_dataclass(obj):
-        return ExtType(4, json.dumps(dataclasses.asdict(obj), cls=CustomJSONEncoder).encode())
+        return ExtType(ExtendedType.DATACLASS, json.dumps(dataclasses.asdict(obj), cls=CustomJSONEncoder).encode())
 
     return f'no encoder for {obj}'
 
 
 def msgpack_decoder(code, data):
-    if code == 1:
-        return Decimal(data.decode())
-    elif code == 2:
-        return datetime.fromisoformat(data.decode())
-    elif code == 3:
-        return date.fromisoformat(data.decode())
-    elif code == 4:
-        return json.loads(data)
+    match code:
+        case ExtendedType.DECIMAL:
+            return Decimal(data.decode())
+        case ExtendedType.DATETIME:
+            return datetime.fromisoformat(data.decode())
+        case ExtendedType.DATE:
+            return date.fromisoformat(data.decode())
+        case ExtendedType.DATACLASS:
+            return json.loads(data)
 
     return f'no decoder for type {code}'
 
